=========
Changelog
=========

0.7.0 (2025-08-05)
==================

Feature release for Open Telemetry support.

* Added ``otel`` package extra and ``maykin_common.otel.setup_otel`` helper to
  instrument projects with Open Telemetry. See the documentation for details.
* Added test coverage for the throttling mixin and refactored it a bit.
* Fixed a reference to a stylesheet that no longer exists.

0.6.0 (2025-07-10)
==================

PDF utilities feature release.

* 💥 Renamed ``render_to_pdf`` to ``render_template_to_pdf``.
* Exposed helper ``render_to_pdf`` to render HTML to PDF without needing the template
  engine.
* Added ``variant`` option, defaulting to ``pdf/ua-1`` (accessible PDFs).

0.5.0 (2025-07-04)
==================

Feature release.

* Added a post-processing hook for ``URLField(default="")`` schemas generated by
  drf-spectacular, which don't pass OpenAPI linting/validation.

0.4.0 (2025-06-23)
==================

* Added ``vcr`` extra that adds VCRMixin and TestCases.

0.3.2 (2025-06-11)
==================

Small CSS bugfix.

* Fixed the appearance of tab titles (larger font-size and line height).
* Fixed the display-as-flex rule for the tab panel content when visible.

0.3.1 (2025-06-11)
==================

Fixed packaging mistake.

* Fixed missing Javascript assets in published package.

0.3.0 (2025-06-11)
==================

Feature and cleanup release.

* Restructured the documentation.
* [#6] The ``pdf`` module now has 100% test coverage.
* [#5] Ported the API project templates and static assets and made the landing page
  accessible.
* Improved the DX for running tests locally.
